############
 Installing
############

****************
 Using datasets
****************

To install the package, you can use the following command:

.. code:: bash

   pip install anemoi-datasets

*******************
 Creating datasets
*******************

.. code:: bash

   pip install anemoi-datasets[create]

**************
 Contributing
**************

.. code:: bash

   git clone ...
   cd anemoi-datasets
   pip install .[dev]
   pip install -r docs/requirements.txt

You may also have to install pandoc on MacOS:

.. code:: bash

   brew install pandoc

..
   TODO: Make sure to update `setup.py`
   to reflect these options
